smartcard.CardMonitoring.CardMonitor.__CardMonitorSingleton

# ``smartcard`.`CardMonitoring`.`CardMonitor`.`__CardMonitorSingleton``

class documentation

`class __CardMonitorSingleton(Observable):`

View In Hierarchy

The real smart card monitor class.

A single instance of this class is created by the public CardMonitor class.

Method | `__init__` | Undocumented
Method | `__str__` | Undocumented
Method | `addObserver` | Add an observer.
Method | `deleteObserver` | Remove an observer.
Instance Variable | `rmthread` | Undocumented

Inherited from `Observable`:

Method | `clearChanged` | Undocumented
Method | `countObservers` | Undocumented
Method | `deleteObservers` | Undocumented
Method | `hasChanged` | Undocumented
Method | `notifyObservers` | If 'changed' indicates that this object has changed, notify all its observers, then call clearChanged(). Each observer has its update() called with two arguments: this observable object and the generic 'arg'.
Method | `setChanged` | Undocumented
Instance Variable | `changed` | Undocumented
Instance Variable | `obs` | Undocumented

Inherited from `Synchronization` (via `Observable`):

Instance Variable | `mutex` | Undocumented

def __init__(self):
overrides `smartcard.Observer.Observable.__init__`

Undocumented

def __str__(self):

Undocumented

def addObserver(self, observer):
overrides `smartcard.Observer.Observable.addObserver`

Add an observer.

We only start the card monitoring thread when there are observers.

def deleteObserver(self, observer):
overrides `smartcard.Observer.Observable.deleteObserver`

Remove an observer.

We delete the `CardMonitoringThread` reference when there are no more observers.

rmthread =

Undocumented